@@ -8,6 +8,10 @@ from couchdbcurl.client import ResourceNotFound
     
 class CouchBackend(object):
 
+    supports_object_permissions = False
+    supports_anonymous_user = False
+    supports_inactive_user = True
+
     def __init__(self):
         self.db = django_couch.db(settings.COUCHDB_AUTH_DB)
 
